import sharp from 'sharp';
import type { SharpOptions, ResizeOptions } from 'sharp';
import { Hashes } from '../hash';

export class Image {
	private thumbnailCache : Buffer = null;
	private thumbnailHash : string = null;
	private blankCache : Buffer = null;
	private blankHash : string = null;
	constructor () {

	}
	public async thumbnail (path : string, width : number, height: number) : Promise<Buffer>{
		const hash : string = Hashes.stringHash(`${path},${width},${height}`);
		if (hash !== this.thumbnailHash) {
			const options : ResizeOptions = {
				width,
				height,
				fit: sharp.fit.fill
			}
			this.thumbnailCache = await sharp(path).resize(options).jpeg().toBuffer();
			this.thumbnailHash = hash;
		}
		return this.thumbnailCache;
	}

	public async blank (width : number, height : number) {
		const hash : string = Hashes.stringHash(`${width},${height}`);
		if (hash !== this.blankHash) {
			const options : SharpOptions = {
				create: {
					width,
					height,
					channels: 3,
					background: { r: 125, g: 125, b: 125 }
				}
			};
			this.blankCache = await sharp(options).jpeg().toBuffer();
			this.blankHash = hash;
		}
		return this.blankCache;
	}
}

module.exports = { Image };